local bn_assets = require("BattleNetwork.Assets")

---@type BombLib
local BombLib = require("dev.konstinople.library.bomb")

local bomb = BombLib.new_bomb()
bomb:set_bomb_texture(bn_assets.load_texture("bomb.png"))
bomb:set_bomb_animation_path(bn_assets.fetch_animation_path("bomb.animation"))
bomb:set_bomb_shadow(bn_assets.load_texture("bomb_shadow.png"))
bomb:set_execute_sfx(bn_assets.load_audio("lob_bomb.ogg"))

local explosion_texture = Resources.load_texture("explosion.png")
local explosion_sfx = Resources.load_audio("explosion.ogg")
local explosion_animation_path = "explosion.animation"

function card_init(user, props)
    local field = user:field()

    return bomb:create_action(user, function(tile)
        if not tile or not tile:is_walkable() then
            return
        end

        hit_explosion(user, tile)

        local spell = Spell.new(user:team())
        spell:set_facing(user:facing())
        spell:set_hit_props(HitProps.from_card(props, user:context(), Drag.None))

        spell.on_update_func = function(self)
            Resources.play_audio(explosion_sfx)
            self:current_tile():attack_entities(self)
            self:erase()
        end

        field:spawn(spell, tile)
    end)
end

function hit_explosion(user, target_tile)
    local field = user:field()
    local explosion = Artifact.new()

    local explosion_animation = explosion:animation()
    explosion_animation:load(explosion_animation_path)
    explosion_animation:set_state("DEFAULT")

    local sprite = explosion:sprite()
    sprite:set_texture(explosion_texture)
    explosion_animation:apply(sprite)
    sprite:set_layer(-2)

    explosion_animation:on_complete(function()
        explosion:erase()
    end)

    field:spawn(explosion, target_tile)
end
